from distutils.version import LooseVersion

import matplotlib

MPL_VERSION = LooseVersion(matplotlib.__version__)

ROOT = "http://data.astropy.org/testing/astropy/2017-07-12T14:12:26.217559"

IMAGE_REFERENCE_DIR = ROOT + '/1.5.x/'
