



fits2bitmap --help
if errorlevel 1 exit 1
fitscheck --help
if errorlevel 1 exit 1
fitsdiff --help
if errorlevel 1 exit 1
fitsheader --help
if errorlevel 1 exit 1
fitsinfo --help
if errorlevel 1 exit 1
samp_hub --help
if errorlevel 1 exit 1
volint --help
if errorlevel 1 exit 1
wcslint --help
if errorlevel 1 exit 1
exit 0
